# Generated by Django 5.2.11 on 2026-02-25 09:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('system', '0002_chunk_upload_session'),
    ]

    operations = [
        migrations.AlterField(
            model_name='apps',
            name='apps_type',
            field=models.IntegerField(blank=True, choices=[], default=0, help_text='应用类型', null=True, verbose_name='应用类型'),
        ),
        migrations.AlterField(
            model_name='basetask',
            name='task_type',
            field=models.IntegerField(choices=[], db_index=True, default=0, help_text='任务类型', verbose_name='任务类型'),
        ),
        migrations.AlterField(
            model_name='imchatrecordform',
            name='satisfaction_type',
            field=models.IntegerField(blank=True, choices=[], default=5, help_text='满意度', null=True, verbose_name='满意度'),
        ),
        migrations.AlterField(
            model_name='imchattogroupmessage',
            name='msg_stype',
            field=models.IntegerField(blank=True, choices=[], db_index=True, default=0, help_text='消息类型', null=True, verbose_name='消息类型'),
        ),
        migrations.AlterField(
            model_name='imchattouser',
            name='msg_stype',
            field=models.IntegerField(blank=True, choices=[], db_index=True, default=0, help_text='消息类型', null=True, verbose_name='消息类型'),
        ),
        migrations.AlterField(
            model_name='messagecenter',
            name='message_type',
            field=models.IntegerField(choices=[], db_index=True, default=0),
        ),
        migrations.AlterField(
            model_name='messagecenter',
            name='target_type',
            field=models.IntegerField(choices=[], db_index=True, default=0, help_text='目标类型', verbose_name='目标类型'),
        ),
    ]
